# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/mqtt_client_interfaces/srv/new_ros2_mqtt_bridge.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/humble/mqtt_client_interfaces/srv/new_ros2_mqtt_bridge.proto\x12\x36make87_messages_ros2.humble.mqtt_client_interfaces.srv\x1a!make87_messages/core/header.proto\"\xdd\x01\n\x18NewRos2MqttBridgeRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x11\n\tros_topic\x18\x02 \x01(\t\x12\x12\n\nmqtt_topic\x18\x03 \x01(\t\x12\x11\n\tprimitive\x18\x04 \x01(\x08\x12\x18\n\x10inject_timestamp\x18\x05 \x01(\x08\x12\x16\n\x0eros_queue_size\x18\x06 \x01(\r\x12\x10\n\x08mqtt_qos\x18\x07 \x01(\r\x12\x15\n\rmqtt_retained\x18\x08 \x01(\x08\"Z\n\x19NewRos2MqttBridgeResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.mqtt_client_interfaces.srv.new_ros2_mqtt_bridge_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NEWROS2MQTTBRIDGEREQUEST']._serialized_start=177
  _globals['_NEWROS2MQTTBRIDGEREQUEST']._serialized_end=398
  _globals['_NEWROS2MQTTBRIDGERESPONSE']._serialized_start=400
  _globals['_NEWROS2MQTTBRIDGERESPONSE']._serialized_end=490
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.nav_msgs.msg import path_pb2 as _path_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IsPathValidRequest(_message.Message):
    __slots__ = ["path"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    path: _path_pb2.Path
    def __init__(self, path: _Optional[_Union[_path_pb2.Path, _Mapping]] = ...) -> None: ...

class IsPathValidResponse(_message.Message):
    __slots__ = ["is_valid", "invalid_pose_indices"]
    IS_VALID_FIELD_NUMBER: _ClassVar[int]
    INVALID_POSE_INDICES_FIELD_NUMBER: _ClassVar[int]
    is_valid: bool
    invalid_pose_indices: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, is_valid: bool = ..., invalid_pose_indices: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EntityFactory(_message.Message):
    __slots__ = ["name", "allow_renaming", "sdf", "sdf_filename", "clone_name", "pose", "relative_to"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ALLOW_RENAMING_FIELD_NUMBER: _ClassVar[int]
    SDF_FIELD_NUMBER: _ClassVar[int]
    SDF_FILENAME_FIELD_NUMBER: _ClassVar[int]
    CLONE_NAME_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    RELATIVE_TO_FIELD_NUMBER: _ClassVar[int]
    name: str
    allow_renaming: bool
    sdf: str
    sdf_filename: str
    clone_name: str
    pose: _pose_pb2.Pose
    relative_to: str
    def __init__(self, name: _Optional[str] = ..., allow_renaming: bool = ..., sdf: _Optional[str] = ..., sdf_filename: _Optional[str] = ..., clone_name: _Optional[str] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., relative_to: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LandmarkEntry(_message.Message):
    __slots__ = ["header", "id", "tracking_from_landmark_transform", "translation_weight", "rotation_weight"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    TRACKING_FROM_LANDMARK_TRANSFORM_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_WEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROTATION_WEIGHT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    id: str
    tracking_from_landmark_transform: _pose_pb2.Pose
    translation_weight: float
    rotation_weight: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., id: _Optional[str] = ..., tracking_from_landmark_transform: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., translation_weight: _Optional[float] = ..., rotation_weight: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/delphi_mrr_msgs/msg/vehicle_state_msg2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/delphi_mrr_msgs/msg/vehicle_state_msg2.proto\x12\x30make87_messages_ros2.rolling.delphi_mrr_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xab\x02\n\x10VehicleStateMsg2\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x1a\n\x12\x66sm_yaw_rate_valid\x18\x02 \x01(\x08\x12\x14\n\x0c\x66sm_yaw_rate\x18\x03 \x01(\x02\x12\x1d\n\x15\x63\x61n_vehicle_index_4fa\x18\x04 \x01(\r\x12\x1c\n\x14\x66sm_vehicle_velocity\x18\x05 \x01(\x02\x12!\n\x19\x63\x61n_steering_whl_angle_qf\x18\x06 \x01(\x08\x12\"\n\x1a\x66sm_vehicle_velocity_valid\x18\x07 \x01(\x08\x12\x1e\n\x16\x63\x61n_steering_whl_angle\x18\x08 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.delphi_mrr_msgs.msg.vehicle_state_msg2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_VEHICLESTATEMSG2']._serialized_start=184
  _globals['_VEHICLESTATEMSG2']._serialized_end=483
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PointOfInterestStatus(_message.Message):
    __slots__ = ["guid", "distance", "heading", "x_position", "y_position", "params"]
    GUID_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_FIELD_NUMBER: _ClassVar[int]
    HEADING_FIELD_NUMBER: _ClassVar[int]
    X_POSITION_FIELD_NUMBER: _ClassVar[int]
    Y_POSITION_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    guid: int
    distance: float
    heading: float
    x_position: float
    y_position: float
    params: str
    def __init__(self, guid: _Optional[int] = ..., distance: _Optional[float] = ..., heading: _Optional[float] = ..., x_position: _Optional[float] = ..., y_position: _Optional[float] = ..., params: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/srv/stream_rate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/mavros_msgs/srv/stream_rate.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.srv\"L\n\x11StreamRateRequest\x12\x11\n\tstream_id\x18\x01 \x01(\r\x12\x14\n\x0cmessage_rate\x18\x02 \x01(\r\x12\x0e\n\x06on_off\x18\x03 \x01(\x08\"\x14\n\x12StreamRateResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.srv.stream_rate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_STREAMRATEREQUEST']._serialized_start=108
  _globals['_STREAMRATEREQUEST']._serialized_end=184
  _globals['_STREAMRATERESPONSE']._serialized_start=186
  _globals['_STREAMRATERESPONSE']._serialized_end=206
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class EStopRequest(_message.Message):
    __slots__ = ["e_stop_on"]
    E_STOP_ON_FIELD_NUMBER: _ClassVar[int]
    e_stop_on: bool
    def __init__(self, e_stop_on: bool = ...) -> None: ...

class EStopResponse(_message.Message):
    __slots__ = ["success", "message"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    message: str
    def __init__(self, success: bool = ..., message: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/delphi_esr_msgs/msg/esr_vehicle2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/humble/delphi_esr_msgs/msg/esr_vehicle2.proto\x12/make87_messages_ros2.humble.delphi_esr_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xc1\x04\n\x0b\x45srVehicle2\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x16\n\x0escan_index_ack\x18\x03 \x01(\r\x12\x1e\n\x16use_angle_misalignment\x18\x04 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x05 \x01(\x08\x12\x16\n\x0ehigh_yaw_angle\x18\x06 \x01(\x05\x12\x18\n\x10mr_only_transmit\x18\x07 \x01(\x08\x12\x18\n\x10lr_only_transmit\x18\x08 \x01(\x08\x12\x1a\n\x12\x61ngle_misalignment\x18\t \x01(\x02\x12\x1f\n\x17lateral_mounting_offset\x18\n \x01(\x02\x12\x19\n\x11radar_cmd_radiate\x18\x0b \x01(\x08\x12\x18\n\x10\x62lockage_disable\x18\x0c \x01(\x08\x12\x16\n\x0emaximum_tracks\x18\r \x01(\r\x12\x1a\n\x12turn_signal_status\x18\x0e \x01(\r\x12\x1e\n\x16vehicle_speed_validity\x18\x0f \x01(\x08\x12\x17\n\x0fmmr_upside_down\x18\x10 \x01(\x08\x12\x15\n\rgrouping_mode\x18\x11 \x01(\r\x12\x14\n\x0cwiper_status\x18\x12 \x01(\x08\x12\x17\n\x0fraw_data_enable\x18\x13 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.delphi_esr_msgs.msg.esr_vehicle2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ESRVEHICLE2']._serialized_start=210
  _globals['_ESRVEHICLE2']._serialized_end=787
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_valdel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_valdel.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\"M\n\tCfgVALDEL\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x0e\n\x06layers\x18\x02 \x01(\r\x12\x11\n\treserved0\x18\x03 \x03(\r\x12\x0c\n\x04keys\x18\x04 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.cfg_valdel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CFGVALDEL']._serialized_start=105
  _globals['_CFGVALDEL']._serialized_end=182
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.ublox_msgs.msg import cfg_valset_cfgdata_pb2 as _cfg_valset_cfgdata_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CfgVALSET(_message.Message):
    __slots__ = ["version", "layers", "reserved0", "cfgdata"]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    LAYERS_FIELD_NUMBER: _ClassVar[int]
    RESERVED0_FIELD_NUMBER: _ClassVar[int]
    CFGDATA_FIELD_NUMBER: _ClassVar[int]
    version: int
    layers: int
    reserved0: _containers.RepeatedScalarFieldContainer[int]
    cfgdata: _containers.RepeatedCompositeFieldContainer[_cfg_valset_cfgdata_pb2.CfgVALSETCfgdata]
    def __init__(self, version: _Optional[int] = ..., layers: _Optional[int] = ..., reserved0: _Optional[_Iterable[int]] = ..., cfgdata: _Optional[_Iterable[_Union[_cfg_valset_cfgdata_pb2.CfgVALSETCfgdata, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.moveit_msgs.msg import move_it_error_codes_pb2 as _move_it_error_codes_pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import robot_state_pb2 as _robot_state_pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import robot_trajectory_pb2 as _robot_trajectory_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MotionPlanResponse(_message.Message):
    __slots__ = ["trajectory_start", "group_name", "trajectory", "planning_time", "error_code"]
    TRAJECTORY_START_FIELD_NUMBER: _ClassVar[int]
    GROUP_NAME_FIELD_NUMBER: _ClassVar[int]
    TRAJECTORY_FIELD_NUMBER: _ClassVar[int]
    PLANNING_TIME_FIELD_NUMBER: _ClassVar[int]
    ERROR_CODE_FIELD_NUMBER: _ClassVar[int]
    trajectory_start: _robot_state_pb2.RobotState
    group_name: str
    trajectory: _robot_trajectory_pb2.RobotTrajectory
    planning_time: float
    error_code: _move_it_error_codes_pb2.MoveItErrorCodes
    def __init__(self, trajectory_start: _Optional[_Union[_robot_state_pb2.RobotState, _Mapping]] = ..., group_name: _Optional[str] = ..., trajectory: _Optional[_Union[_robot_trajectory_pb2.RobotTrajectory, _Mapping]] = ..., planning_time: _Optional[float] = ..., error_code: _Optional[_Union[_move_it_error_codes_pb2.MoveItErrorCodes, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.flexbe_msgs.msg import container_pb2 as _container_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ContainerStructure(_message.Message):
    __slots__ = ["behavior_id", "containers"]
    BEHAVIOR_ID_FIELD_NUMBER: _ClassVar[int]
    CONTAINERS_FIELD_NUMBER: _ClassVar[int]
    behavior_id: int
    containers: _containers.RepeatedCompositeFieldContainer[_container_pb2.Container]
    def __init__(self, behavior_id: _Optional[int] = ..., containers: _Optional[_Iterable[_Union[_container_pb2.Container, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CfgHNR(_message.Message):
    __slots__ = ["header", "high_nav_rate", "reserved0"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    HIGH_NAV_RATE_FIELD_NUMBER: _ClassVar[int]
    RESERVED0_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    high_nav_rate: int
    reserved0: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., high_nav_rate: _Optional[int] = ..., reserved0: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import quaternion_pb2 as _quaternion_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QuaternionStamped(_message.Message):
    __slots__ = ["header", "quaternion"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    QUATERNION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    quaternion: _quaternion_pb2.Quaternion
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., quaternion: _Optional[_Union[_quaternion_pb2.Quaternion, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LaneletMapBin(_message.Message):
    __slots__ = ["header", "version_map_format", "version_map", "name_map", "data"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VERSION_MAP_FORMAT_FIELD_NUMBER: _ClassVar[int]
    VERSION_MAP_FIELD_NUMBER: _ClassVar[int]
    NAME_MAP_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    version_map_format: str
    version_map: str
    name_map: str
    data: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., version_map_format: _Optional[str] = ..., version_map: _Optional[str] = ..., name_map: _Optional[str] = ..., data: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ros2cli_test_interfaces/srv/short_varied_multi_nested.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ros2cli_test_interfaces.msg import short_varied_nested_pb2 as make87__messages__ros2_dot_humble_dot_ros2cli__test__interfaces_dot_msg_dot_short__varied__nested__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWmake87_messages_ros2/humble/ros2cli_test_interfaces/srv/short_varied_multi_nested.proto\x12\x37make87_messages_ros2.humble.ros2cli_test_interfaces.srv\x1a!make87_messages/core/header.proto\x1aQmake87_messages_ros2/humble/ros2cli_test_interfaces/msg/short_varied_nested.proto\"\xb6\x01\n\x1dShortVariedMultiNestedRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12g\n\x13short_varied_nested\x18\x02 \x01(\x0b\x32J.make87_messages_ros2.humble.ros2cli_test_interfaces.msg.ShortVariedNested\"b\n\x1eShortVariedMultiNestedResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x12\n\nbool_value\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ros2cli_test_interfaces.srv.short_varied_multi_nested_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SHORTVARIEDMULTINESTEDREQUEST']._serialized_start=267
  _globals['_SHORTVARIEDMULTINESTEDREQUEST']._serialized_end=449
  _globals['_SHORTVARIEDMULTINESTEDRESPONSE']._serialized_start=451
  _globals['_SHORTVARIEDMULTINESTEDRESPONSE']._serialized_end=549
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/srv/get_position_ik.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import move_it_error_codes_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_move__it__error__codes__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import position_ik_request_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_position__ik__request__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/moveit_msgs/srv/get_position_ik.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.srv\x1a\x44make87_messages_ros2/jazzy/moveit_msgs/msg/move_it_error_codes.proto\x1a\x44make87_messages_ros2/jazzy/moveit_msgs/msg/position_ik_request.proto\x1a<make87_messages_ros2/jazzy/moveit_msgs/msg/robot_state.proto\"i\n\x14GetPositionIKRequest\x12Q\n\nik_request\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.jazzy.moveit_msgs.msg.PositionIKRequest\"\xb3\x01\n\x15GetPositionIKResponse\x12H\n\x08solution\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.moveit_msgs.msg.RobotState\x12P\n\nerror_code\x18\x02 \x01(\x0b\x32<.make87_messages_ros2.jazzy.moveit_msgs.msg.MoveItErrorCodesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.srv.get_position_ik_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETPOSITIONIKREQUEST']._serialized_start=314
  _globals['_GETPOSITIONIKREQUEST']._serialized_end=419
  _globals['_GETPOSITIONIKRESPONSE']._serialized_start=422
  _globals['_GETPOSITIONIKRESPONSE']._serialized_end=601
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/psdk_interfaces/msg/flight_anomaly.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/psdk_interfaces/msg/flight_anomaly.proto\x12/make87_messages_ros2.humble.psdk_interfaces.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\x85\x04\n\rFlightAnomaly\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x15\n\rimpact_in_air\x18\x03 \x01(\r\x12\x12\n\nrandom_fly\x18\x04 \x01(\r\x12\x18\n\x10height_ctrl_fail\x18\x05 \x01(\r\x12\x1c\n\x14roll_pitch_ctrl_fail\x18\x06 \x01(\r\x12\x15\n\ryaw_ctrl_fail\x18\x07 \x01(\r\x12\x1b\n\x13\x61ircraft_is_falling\x18\x08 \x01(\r\x12\x1a\n\x12strong_wind_level1\x18\t \x01(\r\x12\x1a\n\x12strong_wind_level2\x18\n \x01(\r\x12\"\n\x1a\x63ompass_installation_error\x18\x0b \x01(\r\x12\x1e\n\x16imu_installation_error\x18\x0c \x01(\r\x12\x1c\n\x14\x65sc_temperature_high\x18\r \x01(\r\x12%\n\x1d\x61t_least_one_esc_disconnected\x18\x0e \x01(\r\x12\x15\n\rgps_yaw_error\x18\x0f \x01(\r\x12\x10\n\x08reserved\x18\x10 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.psdk_interfaces.msg.flight_anomaly_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FLIGHTANOMALY']._serialized_start=212
  _globals['_FLIGHTANOMALY']._serialized_end=729
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MrrHeaderAlignmentState(_message.Message):
    __slots__ = ["header", "can_auto_align_hangle_qf", "can_alignment_status", "can_alignment_state", "can_auto_align_hangle_ref", "can_auto_align_hangle"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_AUTO_ALIGN_HANGLE_QF_FIELD_NUMBER: _ClassVar[int]
    CAN_ALIGNMENT_STATUS_FIELD_NUMBER: _ClassVar[int]
    CAN_ALIGNMENT_STATE_FIELD_NUMBER: _ClassVar[int]
    CAN_AUTO_ALIGN_HANGLE_REF_FIELD_NUMBER: _ClassVar[int]
    CAN_AUTO_ALIGN_HANGLE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    can_auto_align_hangle_qf: int
    can_alignment_status: int
    can_alignment_state: int
    can_auto_align_hangle_ref: float
    can_auto_align_hangle: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., can_auto_align_hangle_qf: _Optional[int] = ..., can_alignment_status: _Optional[int] = ..., can_alignment_state: _Optional[int] = ..., can_auto_align_hangle_ref: _Optional[float] = ..., can_auto_align_hangle: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/topic_tools_interfaces/srv/mux_list.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/topic_tools_interfaces/srv/mux_list.proto\x12\x35make87_messages_ros2.jazzy.topic_tools_interfaces.srv\"\x10\n\x0eMuxListRequest\"!\n\x0fMuxListResponse\x12\x0e\n\x06topics\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.topic_tools_interfaces.srv.mux_list_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MUXLISTREQUEST']._serialized_start=127
  _globals['_MUXLISTREQUEST']._serialized_end=143
  _globals['_MUXLISTRESPONSE']._serialized_start=145
  _globals['_MUXLISTRESPONSE']._serialized_end=178
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PathPoint(_message.Message):
    __slots__ = ["pose", "longitudinal_velocity_mps", "lateral_velocity_mps", "heading_rate_rps", "is_final"]
    POSE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDINAL_VELOCITY_MPS_FIELD_NUMBER: _ClassVar[int]
    LATERAL_VELOCITY_MPS_FIELD_NUMBER: _ClassVar[int]
    HEADING_RATE_RPS_FIELD_NUMBER: _ClassVar[int]
    IS_FINAL_FIELD_NUMBER: _ClassVar[int]
    pose: _pose_pb2.Pose
    longitudinal_velocity_mps: float
    lateral_velocity_mps: float
    heading_rate_rps: float
    is_final: bool
    def __init__(self, pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., longitudinal_velocity_mps: _Optional[float] = ..., lateral_velocity_mps: _Optional[float] = ..., heading_rate_rps: _Optional[float] = ..., is_final: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.ros2cli_test_interfaces.msg import short_varied_nested_pb2 as _short_varied_nested_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ShortVariedMultiNested(_message.Message):
    __slots__ = ["header", "short_varied_nested"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SHORT_VARIED_NESTED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    short_varied_nested: _short_varied_nested_pb2.ShortVariedNested
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., short_varied_nested: _Optional[_Union[_short_varied_nested_pb2.ShortVariedNested, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StringArrays(_message.Message):
    __slots__ = ["header", "ub_string_static_array_value", "ub_string_ub_array_value", "ub_string_dynamic_array_value", "string_dynamic_array_value", "string_static_array_value", "string_bounded_array_value", "def_string_dynamic_array_value", "def_string_static_array_value", "def_string_bounded_array_value", "def_various_quotes", "def_various_commas"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    UB_STRING_STATIC_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    UB_STRING_UB_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    UB_STRING_DYNAMIC_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_DYNAMIC_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_STATIC_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_BOUNDED_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    DEF_STRING_DYNAMIC_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    DEF_STRING_STATIC_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    DEF_STRING_BOUNDED_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    DEF_VARIOUS_QUOTES_FIELD_NUMBER: _ClassVar[int]
    DEF_VARIOUS_COMMAS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ub_string_static_array_value: _containers.RepeatedScalarFieldContainer[str]
    ub_string_ub_array_value: _containers.RepeatedScalarFieldContainer[str]
    ub_string_dynamic_array_value: _containers.RepeatedScalarFieldContainer[str]
    string_dynamic_array_value: _containers.RepeatedScalarFieldContainer[str]
    string_static_array_value: _containers.RepeatedScalarFieldContainer[str]
    string_bounded_array_value: _containers.RepeatedScalarFieldContainer[str]
    def_string_dynamic_array_value: _containers.RepeatedScalarFieldContainer[str]
    def_string_static_array_value: _containers.RepeatedScalarFieldContainer[str]
    def_string_bounded_array_value: _containers.RepeatedScalarFieldContainer[str]
    def_various_quotes: _containers.RepeatedScalarFieldContainer[str]
    def_various_commas: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ub_string_static_array_value: _Optional[_Iterable[str]] = ..., ub_string_ub_array_value: _Optional[_Iterable[str]] = ..., ub_string_dynamic_array_value: _Optional[_Iterable[str]] = ..., string_dynamic_array_value: _Optional[_Iterable[str]] = ..., string_static_array_value: _Optional[_Iterable[str]] = ..., string_bounded_array_value: _Optional[_Iterable[str]] = ..., def_string_dynamic_array_value: _Optional[_Iterable[str]] = ..., def_string_static_array_value: _Optional[_Iterable[str]] = ..., def_string_bounded_array_value: _Optional[_Iterable[str]] = ..., def_various_quotes: _Optional[_Iterable[str]] = ..., def_various_commas: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marti_nav_msgs/srv/plan_route.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.marti_nav_msgs.msg import route_pb2 as make87__messages__ros2_dot_rolling_dot_marti__nav__msgs_dot_msg_dot_route__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/rolling/marti_nav_msgs/srv/plan_route.proto\x12/make87_messages_ros2.rolling.marti_nav_msgs.srv\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a;make87_messages_ros2/rolling/marti_nav_msgs/msg/route.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xb9\x01\n\x10PlanRouteRequest\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12G\n\twaypoints\x18\x02 \x03(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12\x19\n\x11plan_from_vehicle\x18\x03 \x01(\x08\"\x8a\x01\n\x11PlanRouteResponse\x12\x45\n\x05route\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.rolling.marti_nav_msgs.msg.Route\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0c\n\x04\x63ost\x18\x04 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marti_nav_msgs.srv.plan_route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLANROUTEREQUEST']._serialized_start=294
  _globals['_PLANROUTEREQUEST']._serialized_end=479
  _globals['_PLANROUTERESPONSE']._serialized_start=482
  _globals['_PLANROUTERESPONSE']._serialized_end=620
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rcss3d_agent_msgs/msg/effector.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rcss3d_agent_msgs.msg import beam_pb2 as make87__messages__ros2_dot_rolling_dot_rcss3d__agent__msgs_dot_msg_dot_beam__pb2
from make87_messages_ros2.rolling.rcss3d_agent_msgs.msg import hinge_joint_vel_pb2 as make87__messages__ros2_dot_rolling_dot_rcss3d__agent__msgs_dot_msg_dot_hinge__joint__vel__pb2
from make87_messages_ros2.rolling.rcss3d_agent_msgs.msg import say_pb2 as make87__messages__ros2_dot_rolling_dot_rcss3d__agent__msgs_dot_msg_dot_say__pb2
from make87_messages_ros2.rolling.rcss3d_agent_msgs.msg import universal_joint_vel_pb2 as make87__messages__ros2_dot_rolling_dot_rcss3d__agent__msgs_dot_msg_dot_universal__joint__vel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/rcss3d_agent_msgs/msg/effector.proto\x12\x32make87_messages_ros2.rolling.rcss3d_agent_msgs.msg\x1a=make87_messages_ros2/rolling/rcss3d_agent_msgs/msg/beam.proto\x1aHmake87_messages_ros2/rolling/rcss3d_agent_msgs/msg/hinge_joint_vel.proto\x1a<make87_messages_ros2/rolling/rcss3d_agent_msgs/msg/say.proto\x1aLmake87_messages_ros2/rolling/rcss3d_agent_msgs/msg/universal_joint_vel.proto\"\xdc\x02\n\x08\x45\x66\x66\x65\x63tor\x12[\n\x10hinge_joint_vels\x18\x01 \x03(\x0b\x32\x41.make87_messages_ros2.rolling.rcss3d_agent_msgs.msg.HingeJointVel\x12\x63\n\x14universal_joint_vels\x18\x02 \x03(\x0b\x32\x45.make87_messages_ros2.rolling.rcss3d_agent_msgs.msg.UniversalJointVel\x12G\n\x05\x62\x65\x61ms\x18\x03 \x03(\x0b\x32\x38.make87_messages_ros2.rolling.rcss3d_agent_msgs.msg.Beam\x12\x45\n\x04says\x18\x04 \x03(\x0b\x32\x37.make87_messages_ros2.rolling.rcss3d_agent_msgs.msg.Sayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rcss3d_agent_msgs.msg.effector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_EFFECTOR']._serialized_start=399
  _globals['_EFFECTOR']._serialized_end=747
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rosbag2_test_msgdefs/srv/basic_srv.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/rosbag2_test_msgdefs/srv/basic_srv.proto\x12\x33make87_messages_ros2.jazzy.rosbag2_test_msgdefs.srv\"\x1e\n\x0f\x42\x61sicSrvRequest\x12\x0b\n\x03req\x18\x01 \x01(\t\" \n\x10\x42\x61sicSrvResponse\x12\x0c\n\x04resp\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rosbag2_test_msgdefs.srv.basic_srv_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BASICSRVREQUEST']._serialized_start=124
  _globals['_BASICSRVREQUEST']._serialized_end=154
  _globals['_BASICSRVRESPONSE']._serialized_start=156
  _globals['_BASICSRVRESPONSE']._serialized_end=188
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rmf_traffic_msgs/srv/register_query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import schedule_identity_pb2 as make87__messages__ros2_dot_humble_dot_rmf__traffic__msgs_dot_msg_dot_schedule__identity__pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import schedule_query_pb2 as make87__messages__ros2_dot_humble_dot_rmf__traffic__msgs_dot_msg_dot_schedule__query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/humble/rmf_traffic_msgs/srv/register_query.proto\x12\x30make87_messages_ros2.humble.rmf_traffic_msgs.srv\x1a!make87_messages/core/header.proto\x1aHmake87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_identity.proto\x1a\x45make87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_query.proto\"\x94\x01\n\x14RegisterQueryRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12N\n\x05query\x18\x02 \x01(\x0b\x32?.make87_messages_ros2.humble.rmf_traffic_msgs.msg.ScheduleQuery\"\xbb\x01\n\x15RegisterQueryResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12S\n\x07node_id\x18\x02 \x01(\x0b\x32\x42.make87_messages_ros2.humble.rmf_traffic_msgs.msg.ScheduleIdentity\x12\x10\n\x08query_id\x18\x03 \x01(\x04\x12\r\n\x05\x65rror\x18\x04 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rmf_traffic_msgs.srv.register_query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_REGISTERQUERYREQUEST']._serialized_start=304
  _globals['_REGISTERQUERYREQUEST']._serialized_end=452
  _globals['_REGISTERQUERYRESPONSE']._serialized_start=455
  _globals['_REGISTERQUERYRESPONSE']._serialized_end=642
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.ublox_msgs.msg import rxm_svsisv_pb2 as _rxm_svsisv_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RxmSVSI(_message.Message):
    __slots__ = ["i_tow", "week", "num_vis", "num_sv", "sv"]
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    WEEK_FIELD_NUMBER: _ClassVar[int]
    NUM_VIS_FIELD_NUMBER: _ClassVar[int]
    NUM_SV_FIELD_NUMBER: _ClassVar[int]
    SV_FIELD_NUMBER: _ClassVar[int]
    i_tow: int
    week: int
    num_vis: int
    num_sv: int
    sv: _containers.RepeatedCompositeFieldContainer[_rxm_svsisv_pb2.RxmSVSISV]
    def __init__(self, i_tow: _Optional[int] = ..., week: _Optional[int] = ..., num_vis: _Optional[int] = ..., num_sv: _Optional[int] = ..., sv: _Optional[_Iterable[_Union[_rxm_svsisv_pb2.RxmSVSISV, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.ublox_msgs.msg import nav_satsv_pb2 as _nav_satsv_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NavSAT(_message.Message):
    __slots__ = ["i_tow", "version", "num_svs", "reserved0", "sv"]
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NUM_SVS_FIELD_NUMBER: _ClassVar[int]
    RESERVED0_FIELD_NUMBER: _ClassVar[int]
    SV_FIELD_NUMBER: _ClassVar[int]
    i_tow: int
    version: int
    num_svs: int
    reserved0: _containers.RepeatedScalarFieldContainer[int]
    sv: _containers.RepeatedCompositeFieldContainer[_nav_satsv_pb2.NavSATSV]
    def __init__(self, i_tow: _Optional[int] = ..., version: _Optional[int] = ..., num_svs: _Optional[int] = ..., reserved0: _Optional[_Iterable[int]] = ..., sv: _Optional[_Iterable[_Union[_nav_satsv_pb2.NavSATSV, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AudioInfo(_message.Message):
    __slots__ = ["header", "channels", "sample_rate", "sample_format", "bitrate", "coding_format"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CHANNELS_FIELD_NUMBER: _ClassVar[int]
    SAMPLE_RATE_FIELD_NUMBER: _ClassVar[int]
    SAMPLE_FORMAT_FIELD_NUMBER: _ClassVar[int]
    BITRATE_FIELD_NUMBER: _ClassVar[int]
    CODING_FORMAT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    channels: int
    sample_rate: int
    sample_format: str
    bitrate: int
    coding_format: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., channels: _Optional[int] = ..., sample_rate: _Optional[int] = ..., sample_format: _Optional[str] = ..., bitrate: _Optional[int] = ..., coding_format: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/get_joint_properties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/gazebo_msgs/srv/get_joint_properties.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\"/\n\x19GetJointPropertiesRequest\x12\x12\n\njoint_name\x18\x01 \x01(\t\"\x84\x01\n\x1aGetJointPropertiesResponse\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0f\n\x07\x64\x61mping\x18\x02 \x03(\x01\x12\x10\n\x08position\x18\x03 \x03(\x01\x12\x0c\n\x04rate\x18\x04 \x03(\x01\x12\x0f\n\x07success\x18\x05 \x01(\x08\x12\x16\n\x0estatus_message\x18\x06 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.get_joint_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETJOINTPROPERTIESREQUEST']._serialized_start=117
  _globals['_GETJOINTPROPERTIESREQUEST']._serialized_end=164
  _globals['_GETJOINTPROPERTIESRESPONSE']._serialized_start=167
  _globals['_GETJOINTPROPERTIESRESPONSE']._serialized_end=299
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ibeo_msgs/msg/object2221.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ibeo_msgs.msg import point2_di_pb2 as make87__messages__ros2_dot_jazzy_dot_ibeo__msgs_dot_msg_dot_point2__di__pb2
from make87_messages_ros2.jazzy.ibeo_msgs.msg import size2_d_pb2 as make87__messages__ros2_dot_jazzy_dot_ibeo__msgs_dot_msg_dot_size2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/jazzy/ibeo_msgs/msg/object2221.proto\x12(make87_messages_ros2.jazzy.ibeo_msgs.msg\x1a\x38make87_messages_ros2/jazzy/ibeo_msgs/msg/point2_di.proto\x1a\x36make87_messages_ros2/jazzy/ibeo_msgs/msg/size2_d.proto\"\xc1\x08\n\nObject2221\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0b\n\x03\x61ge\x18\x02 \x01(\r\x12\x16\n\x0eprediction_age\x18\x03 \x01(\r\x12\x1a\n\x12relative_timestamp\x18\x04 \x01(\r\x12K\n\x0freference_point\x18\x05 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Di\x12Q\n\x15reference_point_sigma\x18\x06 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Di\x12I\n\rclosest_point\x18\x07 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Di\x12O\n\x13\x62ounding_box_center\x18\x08 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Di\x12\x1a\n\x12\x62ounding_box_width\x18\t \x01(\r\x12\x1b\n\x13\x62ounding_box_length\x18\n \x01(\r\x12M\n\x11object_box_center\x18\x0b \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Di\x12I\n\x0fobject_box_size\x18\x0c \x01(\x0b\x32\x30.make87_messages_ros2.jazzy.ibeo_msgs.msg.Size2D\x12\x1e\n\x16object_box_orientation\x18\r \x01(\x05\x12M\n\x11\x61\x62solute_velocity\x18\x0e \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Di\x12Q\n\x17\x61\x62solute_velocity_sigma\x18\x0f \x01(\x0b\x32\x30.make87_messages_ros2.jazzy.ibeo_msgs.msg.Size2D\x12M\n\x11relative_velocity\x18\x10 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Di\x12\x16\n\x0e\x63lassification\x18\x11 \x01(\r\x12\x1a\n\x12\x63lassification_age\x18\x12 \x01(\r\x12 \n\x18\x63lassification_certainty\x18\x13 \x01(\r\x12 \n\x18number_of_contour_points\x18\x14 \x01(\r\x12N\n\x12\x63ontour_point_list\x18\x15 \x03(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Dib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ibeo_msgs.msg.object2221_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBJECT2221']._serialized_start=218
  _globals['_OBJECT2221']._serialized_end=1307
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GPSINPUT(_message.Message):
    __slots__ = ["header", "ros2_header", "fix_type", "gps_id", "ignore_flags", "time_week_ms", "time_week", "lat", "lon", "alt", "hdop", "vdop", "vn", "ve", "vd", "speed_accuracy", "horiz_accuracy", "vert_accuracy", "satellites_visible", "yaw"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    FIX_TYPE_FIELD_NUMBER: _ClassVar[int]
    GPS_ID_FIELD_NUMBER: _ClassVar[int]
    IGNORE_FLAGS_FIELD_NUMBER: _ClassVar[int]
    TIME_WEEK_MS_FIELD_NUMBER: _ClassVar[int]
    TIME_WEEK_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    LON_FIELD_NUMBER: _ClassVar[int]
    ALT_FIELD_NUMBER: _ClassVar[int]
    HDOP_FIELD_NUMBER: _ClassVar[int]
    VDOP_FIELD_NUMBER: _ClassVar[int]
    VN_FIELD_NUMBER: _ClassVar[int]
    VE_FIELD_NUMBER: _ClassVar[int]
    VD_FIELD_NUMBER: _ClassVar[int]
    SPEED_ACCURACY_FIELD_NUMBER: _ClassVar[int]
    HORIZ_ACCURACY_FIELD_NUMBER: _ClassVar[int]
    VERT_ACCURACY_FIELD_NUMBER: _ClassVar[int]
    SATELLITES_VISIBLE_FIELD_NUMBER: _ClassVar[int]
    YAW_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    fix_type: int
    gps_id: int
    ignore_flags: int
    time_week_ms: int
    time_week: int
    lat: int
    lon: int
    alt: float
    hdop: float
    vdop: float
    vn: float
    ve: float
    vd: float
    speed_accuracy: float
    horiz_accuracy: float
    vert_accuracy: float
    satellites_visible: int
    yaw: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., fix_type: _Optional[int] = ..., gps_id: _Optional[int] = ..., ignore_flags: _Optional[int] = ..., time_week_ms: _Optional[int] = ..., time_week: _Optional[int] = ..., lat: _Optional[int] = ..., lon: _Optional[int] = ..., alt: _Optional[float] = ..., hdop: _Optional[float] = ..., vdop: _Optional[float] = ..., vn: _Optional[float] = ..., ve: _Optional[float] = ..., vd: _Optional[float] = ..., speed_accuracy: _Optional[float] = ..., horiz_accuracy: _Optional[float] = ..., vert_accuracy: _Optional[float] = ..., satellites_visible: _Optional[int] = ..., yaw: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.scenario_execution_interfaces.msg import scenario_pb2 as _scenario_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExecuteScenarioRequest(_message.Message):
    __slots__ = ["header", "scenario"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SCENARIO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    scenario: _scenario_pb2.Scenario
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., scenario: _Optional[_Union[_scenario_pb2.Scenario, _Mapping]] = ...) -> None: ...

class ExecuteScenarioResponse(_message.Message):
    __slots__ = ["header", "result"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    result: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., result: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rc_reason_msgs/srv/set_load_carrier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_humble_dot_rc__common__msgs_dot_msg_dot_return__code__pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import load_carrier_model_pb2 as make87__messages__ros2_dot_humble_dot_rc__reason__msgs_dot_msg_dot_load__carrier__model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/humble/rc_reason_msgs/srv/set_load_carrier.proto\x12.make87_messages_ros2.humble.rc_reason_msgs.srv\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/rc_common_msgs/msg/return_code.proto\x1aGmake87_messages_ros2/humble/rc_reason_msgs/msg/load_carrier_model.proto\"\x9d\x01\n\x15SetLoadCarrierRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12V\n\x0cload_carrier\x18\x02 \x01(\x0b\x32@.make87_messages_ros2.humble.rc_reason_msgs.msg.LoadCarrierModel\"\x97\x01\n\x16SetLoadCarrierResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12O\n\x0breturn_code\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.humble.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rc_reason_msgs.srv.set_load_carrier_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETLOADCARRIERREQUEST']._serialized_start=296
  _globals['_SETLOADCARRIERREQUEST']._serialized_end=453
  _globals['_SETLOADCARRIERRESPONSE']._serialized_start=456
  _globals['_SETLOADCARRIERRESPONSE']._serialized_end=607
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_scheduler_msgs/msg/trigger.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_scheduler_msgs.msg import payload_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__scheduler__msgs_dot_msg_dot_payload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/rmf_scheduler_msgs/msg/trigger.proto\x12\x31make87_messages_ros2.jazzy.rmf_scheduler_msgs.msg\x1a?make87_messages_ros2/jazzy/rmf_scheduler_msgs/msg/payload.proto\"\x93\x01\n\x07Trigger\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncreated_at\x18\x02 \x01(\x03\x12\n\n\x02\x61t\x18\x03 \x01(\x03\x12\r\n\x05group\x18\x04 \x01(\t\x12K\n\x07payload\x18\x05 \x01(\x0b\x32:.make87_messages_ros2.jazzy.rmf_scheduler_msgs.msg.Payloadb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_scheduler_msgs.msg.trigger_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TRIGGER']._serialized_start=184
  _globals['_TRIGGER']._serialized_end=331
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/camera_aravis2_msgs/srv/calculate_white_balance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.diagnostic_msgs.msg import key_value_pb2 as make87__messages__ros2_dot_humble_dot_diagnostic__msgs_dot_msg_dot_key__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/humble/camera_aravis2_msgs/srv/calculate_white_balance.proto\x12\x33make87_messages_ros2.humble.camera_aravis2_msgs.srv\x1a!make87_messages/core/header.proto\x1a?make87_messages_ros2/humble/diagnostic_msgs/msg/key_value.proto\"L\n\x1c\x43\x61lculateWhiteBalanceRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\"\xb7\x01\n\x1d\x43\x61lculateWhiteBalanceResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x15\n\ris_successful\x18\x02 \x01(\x08\x12Q\n\x0e\x62\x61lance_ratios\x18\x03 \x03(\x0b\x32\x39.make87_messages_ros2.humble.diagnostic_msgs.msg.KeyValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.camera_aravis2_msgs.srv.calculate_white_balance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CALCULATEWHITEBALANCEREQUEST']._serialized_start=238
  _globals['_CALCULATEWHITEBALANCEREQUEST']._serialized_end=314
  _globals['_CALCULATEWHITEBALANCERESPONSE']._serialized_start=317
  _globals['_CALCULATEWHITEBALANCERESPONSE']._serialized_end=500
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GlobalBundleAdjustmentRequest(_message.Message):
    __slots__ = ["header", "type", "iterations", "pixel_variance", "voc_matches"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ITERATIONS_FIELD_NUMBER: _ClassVar[int]
    PIXEL_VARIANCE_FIELD_NUMBER: _ClassVar[int]
    VOC_MATCHES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    type: int
    iterations: int
    pixel_variance: float
    voc_matches: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., type: _Optional[int] = ..., iterations: _Optional[int] = ..., pixel_variance: _Optional[float] = ..., voc_matches: bool = ...) -> None: ...

class GlobalBundleAdjustmentResponse(_message.Message):
    __slots__ = ["header"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/puma_motor_msgs/msg/feedback.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/humble/puma_motor_msgs/msg/feedback.proto\x12/make87_messages_ros2.humble.puma_motor_msgs.msg\x1a!make87_messages/core/header.proto\"\xba\x01\n\x08\x46\x65\x65\x64\x62\x61\x63k\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x15\n\rdevice_number\x18\x02 \x01(\r\x12\x13\n\x0b\x64\x65vice_name\x18\x03 \x01(\t\x12\x12\n\nduty_cycle\x18\x04 \x01(\x02\x12\x0f\n\x07\x63urrent\x18\x05 \x01(\x02\x12\x0e\n\x06travel\x18\x06 \x01(\x01\x12\r\n\x05speed\x18\x07 \x01(\x01\x12\x10\n\x08setpoint\x18\x08 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.puma_motor_msgs.msg.feedback_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FEEDBACK']._serialized_start=151
  _globals['_FEEDBACK']._serialized_end=337
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StatusResponse(_message.Message):
    __slots__ = ["header", "code", "message"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    code: int
    message: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., code: _Optional[int] = ..., message: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class UVCoordinate(_message.Message):
    __slots__ = ["u", "v"]
    U_FIELD_NUMBER: _ClassVar[int]
    V_FIELD_NUMBER: _ClassVar[int]
    u: float
    v: float
    def __init__(self, u: _Optional[float] = ..., v: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/topic_tools_interfaces/srv/demux_add.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/topic_tools_interfaces/srv/demux_add.proto\x12\x35make87_messages_ros2.jazzy.topic_tools_interfaces.srv\" \n\x0f\x44\x65muxAddRequest\x12\r\n\x05topic\x18\x01 \x01(\t\"#\n\x10\x44\x65muxAddResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.topic_tools_interfaces.srv.demux_add_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DEMUXADDREQUEST']._serialized_start=128
  _globals['_DEMUXADDREQUEST']._serialized_end=160
  _globals['_DEMUXADDRESPONSE']._serialized_start=162
  _globals['_DEMUXADDRESPONSE']._serialized_end=197
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/esf_status_sens.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/ublox_msgs/msg/esf_status_sens.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\"Y\n\rEsfSTATUSSens\x12\x14\n\x0csens_status1\x18\x01 \x01(\r\x12\x14\n\x0csens_status2\x18\x02 \x01(\r\x12\x0c\n\x04\x66req\x18\x03 \x01(\r\x12\x0e\n\x06\x66\x61ults\x18\x04 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.esf_status_sens_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ESFSTATUSSENS']._serialized_start=110
  _globals['_ESFSTATUSSENS']._serialized_end=199
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/flexbe_msgs/srv/get_userdata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.flexbe_msgs.msg import userdata_info_pb2 as make87__messages__ros2_dot_jazzy_dot_flexbe__msgs_dot_msg_dot_userdata__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/jazzy/flexbe_msgs/srv/get_userdata.proto\x12*make87_messages_ros2.jazzy.flexbe_msgs.srv\x1a>make87_messages_ros2/jazzy/flexbe_msgs/msg/userdata_info.proto\"*\n\x12GetUserdataRequest\x12\x14\n\x0cuserdata_key\x18\x01 \x01(\t\"\x83\x01\n\x13GetUserdataResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12J\n\x08userdata\x18\x03 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.flexbe_msgs.msg.UserdataInfob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.flexbe_msgs.srv.get_userdata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETUSERDATAREQUEST']._serialized_start=173
  _globals['_GETUSERDATAREQUEST']._serialized_end=215
  _globals['_GETUSERDATARESPONSE']._serialized_start=218
  _globals['_GETUSERDATARESPONSE']._serialized_end=349
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.controller_manager_msgs.msg import controller_state_pb2 as _controller_state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListControllersRequest(_message.Message):
    __slots__ = ["header"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ...) -> None: ...

class ListControllersResponse(_message.Message):
    __slots__ = ["header", "controller"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CONTROLLER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    controller: _containers.RepeatedCompositeFieldContainer[_controller_state_pb2.ControllerState]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., controller: _Optional[_Iterable[_Union[_controller_state_pb2.ControllerState, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ptz_action_server_msgs/msg/ptz_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/ptz_action_server_msgs/msg/ptz_state.proto\x12\x35make87_messages_ros2.jazzy.ptz_action_server_msgs.msg\"A\n\x08PtzState\x12\x0c\n\x04mode\x18\x01 \x01(\x05\x12\x0b\n\x03pan\x18\x02 \x01(\x02\x12\x0c\n\x04tilt\x18\x03 \x01(\x02\x12\x0c\n\x04zoom\x18\x04 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ptz_action_server_msgs.msg.ptz_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PTZSTATE']._serialized_start=128
  _globals['_PTZSTATE']._serialized_end=193
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/tf2_msgs/msg/tf_message.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import transform_stamped_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_transform__stamped__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/tf2_msgs/msg/tf_message.proto\x12\'make87_messages_ros2.jazzy.tf2_msgs.msg\x1a\x44make87_messages_ros2/jazzy/geometry_msgs/msg/transform_stamped.proto\"_\n\tTFMessage\x12R\n\ntransforms\x18\x01 \x03(\x0b\x32>.make87_messages_ros2.jazzy.geometry_msgs.msg.TransformStampedb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.tf2_msgs.msg.tf_message_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TFMESSAGE']._serialized_start=171
  _globals['_TFMESSAGE']._serialized_end=266
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InteractiveMarkerFeedback(_message.Message):
    __slots__ = ["header", "ros2_header", "client_id", "marker_name", "control_name", "event_type", "pose", "menu_entry_id", "mouse_point", "mouse_point_valid"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    MARKER_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTROL_NAME_FIELD_NUMBER: _ClassVar[int]
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    MENU_ENTRY_ID_FIELD_NUMBER: _ClassVar[int]
    MOUSE_POINT_FIELD_NUMBER: _ClassVar[int]
    MOUSE_POINT_VALID_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    client_id: str
    marker_name: str
    control_name: str
    event_type: int
    pose: _pose_pb2.Pose
    menu_entry_id: int
    mouse_point: _point_pb2.Point
    mouse_point_valid: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., client_id: _Optional[str] = ..., marker_name: _Optional[str] = ..., control_name: _Optional[str] = ..., event_type: _Optional[int] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., menu_entry_id: _Optional[int] = ..., mouse_point: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., mouse_point_valid: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsfSTATUSSens(_message.Message):
    __slots__ = ["header", "sens_status1", "sens_status2", "freq", "faults"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SENS_STATUS1_FIELD_NUMBER: _ClassVar[int]
    SENS_STATUS2_FIELD_NUMBER: _ClassVar[int]
    FREQ_FIELD_NUMBER: _ClassVar[int]
    FAULTS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    sens_status1: int
    sens_status2: int
    freq: int
    faults: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., sens_status1: _Optional[int] = ..., sens_status2: _Optional[int] = ..., freq: _Optional[int] = ..., faults: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectedMapInfo(_message.Message):
    __slots__ = ["frame_id", "x", "y", "width", "height", "min_z", "max_z"]
    FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    MIN_Z_FIELD_NUMBER: _ClassVar[int]
    MAX_Z_FIELD_NUMBER: _ClassVar[int]
    frame_id: str
    x: float
    y: float
    width: float
    height: float
    min_z: float
    max_z: float
    def __init__(self, frame_id: _Optional[str] = ..., x: _Optional[float] = ..., y: _Optional[float] = ..., width: _Optional[float] = ..., height: _Optional[float] = ..., min_z: _Optional[float] = ..., max_z: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WheelVels(_message.Message):
    __slots__ = ["header", "velocity_left", "velocity_right"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_LEFT_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_RIGHT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    velocity_left: float
    velocity_right: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., velocity_left: _Optional[float] = ..., velocity_right: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ScanPoint2202(_message.Message):
    __slots__ = ["layer", "echo", "transparent_point", "clutter_atmospheric", "ground", "dirt", "horizontal_angle", "radial_distance", "echo_pulse_width"]
    LAYER_FIELD_NUMBER: _ClassVar[int]
    ECHO_FIELD_NUMBER: _ClassVar[int]
    TRANSPARENT_POINT_FIELD_NUMBER: _ClassVar[int]
    CLUTTER_ATMOSPHERIC_FIELD_NUMBER: _ClassVar[int]
    GROUND_FIELD_NUMBER: _ClassVar[int]
    DIRT_FIELD_NUMBER: _ClassVar[int]
    HORIZONTAL_ANGLE_FIELD_NUMBER: _ClassVar[int]
    RADIAL_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    ECHO_PULSE_WIDTH_FIELD_NUMBER: _ClassVar[int]
    layer: int
    echo: int
    transparent_point: bool
    clutter_atmospheric: bool
    ground: bool
    dirt: bool
    horizontal_angle: int
    radial_distance: int
    echo_pulse_width: int
    def __init__(self, layer: _Optional[int] = ..., echo: _Optional[int] = ..., transparent_point: bool = ..., clutter_atmospheric: bool = ..., ground: bool = ..., dirt: bool = ..., horizontal_angle: _Optional[int] = ..., radial_distance: _Optional[int] = ..., echo_pulse_width: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetImuCalibrationRequest(_message.Message):
    __slots__ = ["header", "gyro_bias_x", "gyro_bias_y", "gyro_bias_z"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    GYRO_BIAS_X_FIELD_NUMBER: _ClassVar[int]
    GYRO_BIAS_Y_FIELD_NUMBER: _ClassVar[int]
    GYRO_BIAS_Z_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    gyro_bias_x: float
    gyro_bias_y: float
    gyro_bias_z: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., gyro_bias_x: _Optional[float] = ..., gyro_bias_y: _Optional[float] = ..., gyro_bias_z: _Optional[float] = ...) -> None: ...

class SetImuCalibrationResponse(_message.Message):
    __slots__ = ["header", "success"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sensor_msgs/msg/joy_feedback_array.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.sensor_msgs.msg import joy_feedback_pb2 as make87__messages__ros2_dot_rolling_dot_sensor__msgs_dot_msg_dot_joy__feedback__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/sensor_msgs/msg/joy_feedback_array.proto\x12,make87_messages_ros2.rolling.sensor_msgs.msg\x1a?make87_messages_ros2/rolling/sensor_msgs/msg/joy_feedback.proto\"\\\n\x10JoyFeedbackArray\x12H\n\x05\x61rray\x18\x01 \x03(\x0b\x32\x39.make87_messages_ros2.rolling.sensor_msgs.msg.JoyFeedbackb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sensor_msgs.msg.joy_feedback_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_JOYFEEDBACKARRAY']._serialized_start=184
  _globals['_JOYFEEDBACKARRAY']._serialized_end=276
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/msg/trajectory.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.mavros_msgs.msg import position_target_pb2 as make87__messages__ros2_dot_jazzy_dot_mavros__msgs_dot_msg_dot_position__target__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/jazzy/mavros_msgs/msg/trajectory.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.msg\x1a@make87_messages_ros2/jazzy/mavros_msgs/msg/position_target.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x98\x04\n\nTrajectory\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0c\n\x04type\x18\x02 \x01(\r\x12K\n\x07point_1\x18\x03 \x01(\x0b\x32:.make87_messages_ros2.jazzy.mavros_msgs.msg.PositionTarget\x12K\n\x07point_2\x18\x04 \x01(\x0b\x32:.make87_messages_ros2.jazzy.mavros_msgs.msg.PositionTarget\x12K\n\x07point_3\x18\x05 \x01(\x0b\x32:.make87_messages_ros2.jazzy.mavros_msgs.msg.PositionTarget\x12K\n\x07point_4\x18\x06 \x01(\x0b\x32:.make87_messages_ros2.jazzy.mavros_msgs.msg.PositionTarget\x12K\n\x07point_5\x18\x07 \x01(\x0b\x32:.make87_messages_ros2.jazzy.mavros_msgs.msg.PositionTarget\x12\x13\n\x0bpoint_valid\x18\x08 \x03(\r\x12\x0f\n\x07\x63ommand\x18\t \x03(\r\x12\x14\n\x0ctime_horizon\x18\n \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.msg.trajectory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TRAJECTORY']._serialized_start=228
  _globals['_TRAJECTORY']._serialized_end=764
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import collision_object_pb2 as _collision_object_pb2
from make87_messages_ros2.humble.octomap_msgs.msg import octomap_with_pose_pb2 as _octomap_with_pose_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PlanningSceneWorld(_message.Message):
    __slots__ = ["header", "collision_objects", "octomap"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    COLLISION_OBJECTS_FIELD_NUMBER: _ClassVar[int]
    OCTOMAP_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    collision_objects: _containers.RepeatedCompositeFieldContainer[_collision_object_pb2.CollisionObject]
    octomap: _octomap_with_pose_pb2.OctomapWithPose
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., collision_objects: _Optional[_Iterable[_Union[_collision_object_pb2.CollisionObject, _Mapping]]] = ..., octomap: _Optional[_Union[_octomap_with_pose_pb2.OctomapWithPose, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/sbas_sv_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/sbas_sv_data.proto\x12-make87_messages_ros2.jazzy.ublox_ubx_msgs.msg\"\xa1\x01\n\nSBASSvData\x12\x0c\n\x04svid\x18\x01 \x01(\r\x12\x12\n\nreserved_1\x18\x02 \x01(\r\x12\x0c\n\x04udre\x18\x03 \x01(\r\x12\x0e\n\x06sv_sys\x18\x04 \x01(\r\x12\x12\n\nsv_service\x18\x05 \x01(\r\x12\x12\n\nreserved_2\x18\x06 \x01(\r\x12\x0b\n\x03prc\x18\x07 \x01(\x05\x12\x12\n\nreserved_3\x18\x08 \x03(\r\x12\n\n\x02ic\x18\t \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.sbas_sv_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SBASSVDATA']._serialized_start=116
  _globals['_SBASSVDATA']._serialized_end=277
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MrrStatusSwVersion(_message.Message):
    __slots__ = ["header", "can_pbl_field_revision", "can_pbl_promote_revision", "can_sw_field_revision", "can_sw_promote_revision", "can_sw_release_revision", "can_pbl_release_revision"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_PBL_FIELD_REVISION_FIELD_NUMBER: _ClassVar[int]
    CAN_PBL_PROMOTE_REVISION_FIELD_NUMBER: _ClassVar[int]
    CAN_SW_FIELD_REVISION_FIELD_NUMBER: _ClassVar[int]
    CAN_SW_PROMOTE_REVISION_FIELD_NUMBER: _ClassVar[int]
    CAN_SW_RELEASE_REVISION_FIELD_NUMBER: _ClassVar[int]
    CAN_PBL_RELEASE_REVISION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    can_pbl_field_revision: int
    can_pbl_promote_revision: int
    can_sw_field_revision: int
    can_sw_promote_revision: int
    can_sw_release_revision: int
    can_pbl_release_revision: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., can_pbl_field_revision: _Optional[int] = ..., can_pbl_promote_revision: _Optional[int] = ..., can_sw_field_revision: _Optional[int] = ..., can_sw_promote_revision: _Optional[int] = ..., can_sw_release_revision: _Optional[int] = ..., can_pbl_release_revision: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import wrench_pb2 as _wrench_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ContactState(_message.Message):
    __slots__ = ["header", "info", "collision1_name", "collision2_name", "wrenches", "total_wrench", "contact_positions", "contact_normals", "depths"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    COLLISION1_NAME_FIELD_NUMBER: _ClassVar[int]
    COLLISION2_NAME_FIELD_NUMBER: _ClassVar[int]
    WRENCHES_FIELD_NUMBER: _ClassVar[int]
    TOTAL_WRENCH_FIELD_NUMBER: _ClassVar[int]
    CONTACT_POSITIONS_FIELD_NUMBER: _ClassVar[int]
    CONTACT_NORMALS_FIELD_NUMBER: _ClassVar[int]
    DEPTHS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    info: str
    collision1_name: str
    collision2_name: str
    wrenches: _containers.RepeatedCompositeFieldContainer[_wrench_pb2.Wrench]
    total_wrench: _wrench_pb2.Wrench
    contact_positions: _containers.RepeatedCompositeFieldContainer[_vector3_pb2.Vector3]
    contact_normals: _containers.RepeatedCompositeFieldContainer[_vector3_pb2.Vector3]
    depths: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., info: _Optional[str] = ..., collision1_name: _Optional[str] = ..., collision2_name: _Optional[str] = ..., wrenches: _Optional[_Iterable[_Union[_wrench_pb2.Wrench, _Mapping]]] = ..., total_wrench: _Optional[_Union[_wrench_pb2.Wrench, _Mapping]] = ..., contact_positions: _Optional[_Iterable[_Union[_vector3_pb2.Vector3, _Mapping]]] = ..., contact_normals: _Optional[_Iterable[_Union[_vector3_pb2.Vector3, _Mapping]]] = ..., depths: _Optional[_Iterable[float]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_status.proto\x12/make87_messages_ros2.jazzy.rmf_traffic_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\"\xe5\x01\n\x11NegotiationStatus\x12\x18\n\x10\x63onflict_version\x18\x01 \x01(\x04\x12\x14\n\x0cparticipants\x18\x02 \x03(\x04\x12K\n\nstart_time\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12S\n\x12last_response_time\x18\x04 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Timeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.negotiation_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NEGOTIATIONSTATUS']._serialized_start=188
  _globals['_NEGOTIATIONSTATUS']._serialized_end=417
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.humble.rc_common_msgs.msg import return_code_pb2 as _return_code_pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import collision_detection_pb2 as _collision_detection_pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import compartment_pb2 as _compartment_pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import grasp_pb2 as _grasp_pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import load_carrier_pb2 as _load_carrier_pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import match_pb2 as _match_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CadMatchDetectObjectRequest(_message.Message):
    __slots__ = ["header", "template_id", "pose_frame", "region_of_interest_id", "load_carrier_id", "load_carrier_compartment", "robot_pose", "collision_detection", "pose_prior_ids", "data_acquisition_mode"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    POSE_FRAME_FIELD_NUMBER: _ClassVar[int]
    REGION_OF_INTEREST_ID_FIELD_NUMBER: _ClassVar[int]
    LOAD_CARRIER_ID_FIELD_NUMBER: _ClassVar[int]
    LOAD_CARRIER_COMPARTMENT_FIELD_NUMBER: _ClassVar[int]
    ROBOT_POSE_FIELD_NUMBER: _ClassVar[int]
    COLLISION_DETECTION_FIELD_NUMBER: _ClassVar[int]
    POSE_PRIOR_IDS_FIELD_NUMBER: _ClassVar[int]
    DATA_ACQUISITION_MODE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    template_id: str
    pose_frame: str
    region_of_interest_id: str
    load_carrier_id: str
    load_carrier_compartment: _compartment_pb2.Compartment
    robot_pose: _pose_pb2.Pose
    collision_detection: _collision_detection_pb2.CollisionDetection
    pose_prior_ids: _containers.RepeatedScalarFieldContainer[str]
    data_acquisition_mode: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., template_id: _Optional[str] = ..., pose_frame: _Optional[str] = ..., region_of_interest_id: _Optional[str] = ..., load_carrier_id: _Optional[str] = ..., load_carrier_compartment: _Optional[_Union[_compartment_pb2.Compartment, _Mapping]] = ..., robot_pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., collision_detection: _Optional[_Union[_collision_detection_pb2.CollisionDetection, _Mapping]] = ..., pose_prior_ids: _Optional[_Iterable[str]] = ..., data_acquisition_mode: _Optional[str] = ...) -> None: ...

class CadMatchDetectObjectResponse(_message.Message):
    __slots__ = ["header", "timestamp", "matches", "grasps", "load_carriers", "return_code"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    MATCHES_FIELD_NUMBER: _ClassVar[int]
    GRASPS_FIELD_NUMBER: _ClassVar[int]
    LOAD_CARRIERS_FIELD_NUMBER: _ClassVar[int]
    RETURN_CODE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    timestamp: _time_pb2.Time
    matches: _containers.RepeatedCompositeFieldContainer[_match_pb2.Match]
    grasps: _containers.RepeatedCompositeFieldContainer[_grasp_pb2.Grasp]
    load_carriers: _containers.RepeatedCompositeFieldContainer[_load_carrier_pb2.LoadCarrier]
    return_code: _return_code_pb2.ReturnCode
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., matches: _Optional[_Iterable[_Union[_match_pb2.Match, _Mapping]]] = ..., grasps: _Optional[_Iterable[_Union[_grasp_pb2.Grasp, _Mapping]]] = ..., load_carriers: _Optional[_Iterable[_Union[_load_carrier_pb2.LoadCarrier, _Mapping]]] = ..., return_code: _Optional[_Union[_return_code_pb2.ReturnCode, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PredictedPath(_message.Message):
    __slots__ = ["path", "time_step", "confidence"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TIME_STEP_FIELD_NUMBER: _ClassVar[int]
    CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    path: _containers.RepeatedCompositeFieldContainer[_pose_pb2.Pose]
    time_step: _duration_pb2.Duration
    confidence: float
    def __init__(self, path: _Optional[_Iterable[_Union[_pose_pb2.Pose, _Mapping]]] = ..., time_step: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., confidence: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.rmf_scheduler_msgs.msg import trigger_pb2 as _trigger_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListTriggersRequest(_message.Message):
    __slots__ = ["created_after"]
    CREATED_AFTER_FIELD_NUMBER: _ClassVar[int]
    created_after: int
    def __init__(self, created_after: _Optional[int] = ...) -> None: ...

class ListTriggersResponse(_message.Message):
    __slots__ = ["success", "message", "triggers"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    TRIGGERS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    message: str
    triggers: _containers.RepeatedCompositeFieldContainer[_trigger_pb2.Trigger]
    def __init__(self, success: bool = ..., message: _Optional[str] = ..., triggers: _Optional[_Iterable[_Union[_trigger_pb2.Trigger, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VehicleInfo(_message.Message):
    __slots__ = ["header", "available_info", "sysid", "compid", "autopilot", "type", "system_status", "base_mode", "custom_mode", "mode", "mode_id", "capabilities", "flight_sw_version", "middleware_sw_version", "os_sw_version", "board_version", "flight_custom_version", "vendor_id", "product_id", "uid"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    AVAILABLE_INFO_FIELD_NUMBER: _ClassVar[int]
    SYSID_FIELD_NUMBER: _ClassVar[int]
    COMPID_FIELD_NUMBER: _ClassVar[int]
    AUTOPILOT_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_STATUS_FIELD_NUMBER: _ClassVar[int]
    BASE_MODE_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_MODE_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    MODE_ID_FIELD_NUMBER: _ClassVar[int]
    CAPABILITIES_FIELD_NUMBER: _ClassVar[int]
    FLIGHT_SW_VERSION_FIELD_NUMBER: _ClassVar[int]
    MIDDLEWARE_SW_VERSION_FIELD_NUMBER: _ClassVar[int]
    OS_SW_VERSION_FIELD_NUMBER: _ClassVar[int]
    BOARD_VERSION_FIELD_NUMBER: _ClassVar[int]
    FLIGHT_CUSTOM_VERSION_FIELD_NUMBER: _ClassVar[int]
    VENDOR_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    UID_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    available_info: int
    sysid: int
    compid: int
    autopilot: int
    type: int
    system_status: int
    base_mode: int
    custom_mode: int
    mode: str
    mode_id: int
    capabilities: int
    flight_sw_version: int
    middleware_sw_version: int
    os_sw_version: int
    board_version: int
    flight_custom_version: str
    vendor_id: int
    product_id: int
    uid: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., available_info: _Optional[int] = ..., sysid: _Optional[int] = ..., compid: _Optional[int] = ..., autopilot: _Optional[int] = ..., type: _Optional[int] = ..., system_status: _Optional[int] = ..., base_mode: _Optional[int] = ..., custom_mode: _Optional[int] = ..., mode: _Optional[str] = ..., mode_id: _Optional[int] = ..., capabilities: _Optional[int] = ..., flight_sw_version: _Optional[int] = ..., middleware_sw_version: _Optional[int] = ..., os_sw_version: _Optional[int] = ..., board_version: _Optional[int] = ..., flight_custom_version: _Optional[str] = ..., vendor_id: _Optional[int] = ..., product_id: _Optional[int] = ..., uid: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.marti_visualization_msgs.msg import textured_marker_pb2 as _textured_marker_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TexturedMarkerArray(_message.Message):
    __slots__ = ["markers"]
    MARKERS_FIELD_NUMBER: _ClassVar[int]
    markers: _containers.RepeatedCompositeFieldContainer[_textured_marker_pb2.TexturedMarker]
    def __init__(self, markers: _Optional[_Iterable[_Union[_textured_marker_pb2.TexturedMarker, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/planning_scene.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import transform_stamped_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_transform__stamped__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import allowed_collision_matrix_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_allowed__collision__matrix__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import link_padding_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_link__padding__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import link_scale_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_link__scale__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import object_color_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_object__color__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import planning_scene_world_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_planning__scene__world__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/moveit_msgs/msg/planning_scene.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a\x44make87_messages_ros2/jazzy/geometry_msgs/msg/transform_stamped.proto\x1aImake87_messages_ros2/jazzy/moveit_msgs/msg/allowed_collision_matrix.proto\x1a=make87_messages_ros2/jazzy/moveit_msgs/msg/link_padding.proto\x1a;make87_messages_ros2/jazzy/moveit_msgs/msg/link_scale.proto\x1a=make87_messages_ros2/jazzy/moveit_msgs/msg/object_color.proto\x1a\x45make87_messages_ros2/jazzy/moveit_msgs/msg/planning_scene_world.proto\x1a<make87_messages_ros2/jazzy/moveit_msgs/msg/robot_state.proto\"\x94\x05\n\rPlanningScene\x12\x0c\n\x04name\x18\x01 \x01(\t\x12K\n\x0brobot_state\x18\x02 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.moveit_msgs.msg.RobotState\x12\x18\n\x10robot_model_name\x18\x03 \x01(\t\x12^\n\x16\x66ixed_frame_transforms\x18\x04 \x03(\x0b\x32>.make87_messages_ros2.jazzy.geometry_msgs.msg.TransformStamped\x12\x64\n\x18\x61llowed_collision_matrix\x18\x05 \x01(\x0b\x32\x42.make87_messages_ros2.jazzy.moveit_msgs.msg.AllowedCollisionMatrix\x12M\n\x0clink_padding\x18\x06 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.moveit_msgs.msg.LinkPadding\x12I\n\nlink_scale\x18\x07 \x03(\x0b\x32\x35.make87_messages_ros2.jazzy.moveit_msgs.msg.LinkScale\x12N\n\robject_colors\x18\x08 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.moveit_msgs.msg.ObjectColor\x12M\n\x05world\x18\t \x01(\x0b\x32>.make87_messages_ros2.jazzy.moveit_msgs.msg.PlanningSceneWorld\x12\x0f\n\x07is_diff\x18\n \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.planning_scene_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLANNINGSCENE']._serialized_start=577
  _globals['_PLANNINGSCENE']._serialized_end=1237
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SbgEvent(_message.Message):
    __slots__ = ["header", "time_stamp", "overflow", "offset_0_valid", "offset_1_valid", "offset_2_valid", "offset_3_valid", "time_offset_0", "time_offset_1", "time_offset_2", "time_offset_3"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIME_STAMP_FIELD_NUMBER: _ClassVar[int]
    OVERFLOW_FIELD_NUMBER: _ClassVar[int]
    OFFSET_0_VALID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_1_VALID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_2_VALID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_3_VALID_FIELD_NUMBER: _ClassVar[int]
    TIME_OFFSET_0_FIELD_NUMBER: _ClassVar[int]
    TIME_OFFSET_1_FIELD_NUMBER: _ClassVar[int]
    TIME_OFFSET_2_FIELD_NUMBER: _ClassVar[int]
    TIME_OFFSET_3_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    time_stamp: int
    overflow: bool
    offset_0_valid: bool
    offset_1_valid: bool
    offset_2_valid: bool
    offset_3_valid: bool
    time_offset_0: int
    time_offset_1: int
    time_offset_2: int
    time_offset_3: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., time_stamp: _Optional[int] = ..., overflow: bool = ..., offset_0_valid: bool = ..., offset_1_valid: bool = ..., offset_2_valid: bool = ..., offset_3_valid: bool = ..., time_offset_0: _Optional[int] = ..., time_offset_1: _Optional[int] = ..., time_offset_2: _Optional[int] = ..., time_offset_3: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PenInkProperties(_message.Message):
    __slots__ = ["color", "density"]
    COLOR_FIELD_NUMBER: _ClassVar[int]
    DENSITY_FIELD_NUMBER: _ClassVar[int]
    color: int
    density: float
    def __init__(self, color: _Optional[int] = ..., density: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/game_controller_spl_interfaces/msg/team_info14.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.game_controller_spl_interfaces.msg import robot_info14_pb2 as make87__messages__ros2_dot_rolling_dot_game__controller__spl__interfaces_dot_msg_dot_robot__info14__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/rolling/game_controller_spl_interfaces/msg/team_info14.proto\x12?make87_messages_ros2.rolling.game_controller_spl_interfaces.msg\x1aRmake87_messages_ros2/rolling/game_controller_spl_interfaces/msg/robot_info14.proto\"\xe8\x01\n\nTeamInfo14\x12\x13\n\x0bteam_number\x18\x01 \x01(\r\x12\x13\n\x0bteam_colour\x18\x02 \x01(\r\x12\r\n\x05score\x18\x03 \x01(\r\x12\x14\n\x0cpenalty_shot\x18\x04 \x01(\r\x12\x14\n\x0csingle_shots\x18\x05 \x01(\r\x12\x16\n\x0emessage_budget\x18\x06 \x01(\r\x12]\n\x07players\x18\x07 \x03(\x0b\x32L.make87_messages_ros2.rolling.game_controller_spl_interfaces.msg.RobotInfo14b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.game_controller_spl_interfaces.msg.team_info14_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TEAMINFO14']._serialized_start=235
  _globals['_TEAMINFO14']._serialized_end=467
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geographic_msgs.msg import geo_point_pb2 as _geo_point_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HilGPS(_message.Message):
    __slots__ = ["header", "ros2_header", "fix_type", "geo", "eph", "epv", "vel", "vn", "ve", "vd", "cog", "satellites_visible"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    FIX_TYPE_FIELD_NUMBER: _ClassVar[int]
    GEO_FIELD_NUMBER: _ClassVar[int]
    EPH_FIELD_NUMBER: _ClassVar[int]
    EPV_FIELD_NUMBER: _ClassVar[int]
    VEL_FIELD_NUMBER: _ClassVar[int]
    VN_FIELD_NUMBER: _ClassVar[int]
    VE_FIELD_NUMBER: _ClassVar[int]
    VD_FIELD_NUMBER: _ClassVar[int]
    COG_FIELD_NUMBER: _ClassVar[int]
    SATELLITES_VISIBLE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    fix_type: int
    geo: _geo_point_pb2.GeoPoint
    eph: int
    epv: int
    vel: int
    vn: int
    ve: int
    vd: int
    cog: int
    satellites_visible: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., fix_type: _Optional[int] = ..., geo: _Optional[_Union[_geo_point_pb2.GeoPoint, _Mapping]] = ..., eph: _Optional[int] = ..., epv: _Optional[int] = ..., vel: _Optional[int] = ..., vn: _Optional[int] = ..., ve: _Optional[int] = ..., vd: _Optional[int] = ..., cog: _Optional[int] = ..., satellites_visible: _Optional[int] = ...) -> None: ...
